==> DNaseR_1.0.0.tar.gz: DNaseR/man/DNaseR-package.Rd <==
\name{DNaseR-package}
\alias{DNaseR-package}
\alias{DNaseR}
\docType{package}

\title{ DNase I footprinting analysis of DNase-seq data }
\description{ Strand-specific digital genomic footprinting in DNase-seq data. The cumulative Skellam distribution function (package 'skellam') is used to detect significant normalized count differences of opposed sign at each DNA strand. This is done in order to determine the protein-binding footprint flanks. Preprocessing of the mapped reads is recommended before running DNaseR (e.g., quality checking and removal of sequence specific bias).
}
\details{
\tabular{ll}{
Package: \tab DNaseR\cr
Type: \tab Package\cr
Version: \tab 0.99.1\cr
Date: \tab 2013-09-11\cr
License: \tab GPL-2 + file LICENSE \cr
LazyLoad: \tab yes\cr
}
}

\author{
Pedro Madrigal,

Maintainer: Pedro Madrigal \email{pm@engineering.com}

}
\references{ Madrigal P, Krajewski P (2012) Current bioinformatic approaches to identify DNase I hypersensitive sites and genomic footprints from DNase-seq data. Front Genet 3: 230.\cr 

Neph S, Vierstra J, Stergachis AB, Reynolds AP, Haugen E, Vernot B, Thurman RE, John S, Sandstrom R, Johnson AK, Maurano MT, Humbert R, Rynes E, Wang H, Vong S, Lee K, Bates D, Diegel M, Roach V, Dunn D, Neri J, Schafer A, Hansen RS, Kutyavin T, Giste E, Weaver M, Canfield T, Sabo P, Zhang M, Balasundaram G, Byron R, MacCoss MJ, Akey JM, Bender MA, Groudine M, Kaul R, Stamatoyannopoulos JA (2012) An expansive human regulatory lexicon encoded in transcription factor footprints. Nature 489: 83-90. \cr 

Skellam JG (1946) The frequency distribution of the difference between two Poisson variates belonging to different populations. J R Stat Soc Ser A 109: 296. \cr 

Song L, Crawford GE (2010) DNase-seq: a high-resolution technique for mapping active gene regulatory elements across the genome from mammalian cells. Cold Spring Harb Protoc 2:pdb.prot5384. }

\examples{

## hg18. chrY:1 - 3000Kb reads from DNase-seq dataset wgEncodeUwDgfTh1Aln.bam
## from the ENCODE Project.
##
## Downloaded from:
## http://hgdownload-test.cse.ucsc.edu/goldenPath/hg19/encodeDCC/wgEncodeUwDgf/
## release1/wgEncodeUwDgfTh1Aln.bam

owd <- setwd(tempdir())

bamfile <- "chrY_3Kb_wgEncodeUwDgfTh1Aln.bam"

f <- system.file("extdata", bamfile, package="DNaseR",mustWork = TRUE)

dgf <- footprints(bam=f, chrN="chrY", chrL=3e6, p=1e-9, width=c(6,40), N=2e6)

setwd(owd)
}

==> DNaseR_1.2.0.tar.gz: DNaseR/man/DNaseR-package.Rd <==
\name{DNaseR-package}
\alias{DNaseR-package}
\alias{DNaseR}
\docType{package}

\title{ DNase I footprinting analysis of DNase-seq data }
\description{ Strand-specific digital genomic footprinting in DNase-seq data. The cumulative Skellam distribution function (package 'skellam') is used to detect significant normalized count differences of opposed sign at each DNA strand. This is done in order to determine the protein-binding footprint flanks. Preprocessing of the mapped reads is recommended before running DNaseR (e.g., quality checking and removal of sequence specific bias).
}
\details{
\tabular{ll}{
Package: \tab DNaseR\cr
Type: \tab Package\cr
Version: \tab 1.1.3\cr
Date: \tab 2013-09-12\cr
License: \tab GPL-2 + file LICENSE \cr
LazyLoad: \tab yes\cr
}
}

\author{
Pedro Madrigal,

Maintainer: Pedro Madrigal \email{pm12@sanger.ac.uk}

}
\references{ Madrigal P, Krajewski P (2012) Current bioinformatic approaches to identify DNase I hypersensitive sites and genomic footprints from DNase-seq data. Front Genet 3: 230.\cr 

Neph S, Vierstra J, Stergachis AB, Reynolds AP, Haugen E, Vernot B, Thurman RE, John S, Sandstrom R, Johnson AK, Maurano MT, Humbert R, Rynes E, Wang H, Vong S, Lee K, Bates D, Diegel M, Roach V, Dunn D, Neri J, Schafer A, Hansen RS, Kutyavin T, Giste E, Weaver M, Canfield T, Sabo P, Zhang M, Balasundaram G, Byron R, MacCoss MJ, Akey JM, Bender MA, Groudine M, Kaul R, Stamatoyannopoulos JA (2012) An expansive human regulatory lexicon encoded in transcription factor footprints. Nature 489: 83-90. \cr 

Skellam JG (1946) The frequency distribution of the difference between two Poisson variates belonging to different populations. J R Stat Soc Ser A 109: 296. \cr 

Song L, Crawford GE (2010) DNase-seq: a high-resolution technique for mapping active gene regulatory elements across the genome from mammalian cells. Cold Spring Harb Protoc 2:pdb.prot5384. }

\examples{

## hg18. chrY:1 - 3000Kb reads from DNase-seq dataset wgEncodeUwDgfTh1Aln.bam
## from the ENCODE Project.
##
## Downloaded from:
## http://hgdownload-test.cse.ucsc.edu/goldenPath/hg19/encodeDCC/wgEncodeUwDgf/
## release1/wgEncodeUwDgfTh1Aln.bam

owd <- setwd(tempdir())

bamfile <- "chrY_3Kb_wgEncodeUwDgfTh1Aln.bam"

f <- system.file("extdata", bamfile, package="DNaseR",mustWork = TRUE)

dgf <- footprints(bam=f, chrN="chrY", chrL=3e6, p=1e-9, width=c(6,40), N=2e6)

setwd(owd)
}
